Hallo Kollege,

#if $instance.state.name == 'suggested' ich lade dich zu folgendem Termin ein. #end if #if $instance.state.name == 'notified' der folgende Termin ist noch nicht bestätigt, weil ich noch auf die Zu- oder Absage von mindestens einem Teilnehmer warte. #end if #if $instance.state.name == 'confirmed' folgender Termin ist jetzt bestätigt. #end if #if $instance.state.name == 'rescheduled' der folgende Termin ist verschoben. Ich melde mich mit einem neuen Vorschlag. #end if #if $instance.state.name == 'cancelled' der folgende Termin ist abgesagt. #end if

- Wann: am $dtosl($instance.start_date) um $dtosl($instance.start_time) Uhr
- Titel: $instance.summary ($instance.calendar)

#if $instance.state.name in ('suggested','notified')

Bitte melde dich bei mir, oder gehe in Lino nach Meine offenen erhaltenen Einladungen und klicke auf [Zusagen] oder [Absagen]!

#end if #if $instance.description

Beschreibung:

$instance.description
#end if

Mit freundlichen Grüßen
$instance.user